<?php
/**
 * Define and require all the necessary 'bits and pieces'
 * and build all necessary Static Homepage and Featured area functions.
 * 
 * Note that many of the Home and Featured Widget Area functions have already
 * been created and are located in the /catalyst/lib/ez-structures/ directory.
 * In such cases this file only requires/calls these functions in.
 * No need to re-invent the wheel. :)
 *
 * @package Catalyst
 */

// This lets Catalyst know that a non-Dynamik Child Theme is active.
define( 'CHILD_ACTIVE', true );

// This lets Catalyst know that a HTML5 ready Child Theme is active.
define( 'CATALYST_HTML_FIVE', true );

// This lets Catalyst know that a Responsive Child Theme is active.
define( 'CHILD_RESPONSIVE', true );

// Call Catalyst's core functions.
require_once( get_template_directory() . '/lib/catalyse.php' );

// Re-Declare the $catalyst_child_home global variable
// This variable is declared in /catalyst/lib/catlyse.php based on whether or not
// a Child Theme is active and a home.php file present in that Child Theme's root.
// By re-declaring this variable we can turn the Static Homepage On and Off.
global $catalyst_child_home;

// Manage the placement of open/close wrap tags.
remove_action( 'init', 'catalyst_open_close_wrap' );
add_action( 'init', 'catalyst_child_open_close_wrap' );
/**
 * Hook in the opening and closgin wrap tags.
 *
 * @since 1.0
 */
function catalyst_child_open_close_wrap()
{
	add_action( 'catalyst_hook_before_before_header', 'catalyst_open_site_wrap' );
	add_action( 'catalyst_hook_after_after_footer', 'catalyst_close_site_wrap' );
}

// Manage the placement of navbars.
remove_action( 'init', 'catalyst_hook_navbars' );
add_action( 'init', 'catalyst_child_hook_navbars' );
/**
 * Hook in Navbar 1 and Navbar 2.
 *
 * @since 1.0
 */
function catalyst_child_hook_navbars()
{
	add_action( 'catalyst_hook_header_right', 'catalyst_build_navbar1' );
	add_action( 'catalyst_hook_after_header', 'catalyst_build_navbar2' );
}

// Adjust the hook location of Sidebar 2 to accommodate the Responsive Design structure.
remove_action( 'catalyst_hook_after_content_sidebar_wrap', 'catalyst_sidebar_2' );
add_action( 'catalyst_hook_after_content_wrap', 'catalyst_sidebar_2' );

add_action( 'catalyst_doctype', 'catalyst_child_responsive_viewport', 11 );
/**
 * Add viewport meta tag to the catalyst_doctype hook
 * to force 'real' scale of site when viewed in mobile devices.
 *
 * @since 1.0
 */
function catalyst_child_responsive_viewport()
{
echo '<meta name="viewport" content="width=device-width, initial-scale=1.0"/>' . "\n";
}

add_action( 'get_header', 'catalyst_child_enqueue_scripts' );
/**
 * Enqueue various bits of javascript.
 *
 * @since 1.0
 */
function catalyst_child_enqueue_scripts()
{
	wp_enqueue_script( 'responsive', CATALYST_URL . '/lib/js/catalyst-responsive.js', FALSE, CATALYST_THEME_VERSION, TRUE );
}

/**
 * Enable Custom Post Format functionality.
 */
add_theme_support( 'post-formats', array( 'aside', 'audio', 'chat', 'gallery', 'image', 'link', 'quote', 'status', 'video' ) );
add_theme_support( 'catalyst-post-format-icons' );

/****************************************
	Static Homepage
****************************************/

// Make sure an EZ Home Structure has been selected, the selected EZ Home Structure file is present in the
// specified Catalyst directory and that the $catalyst_child_home variable has a value of 'true' before
// proceeding to require the specified EZ Home Structure file and corresponding function.
if( file_exists( CATALYST_ROOT . '/lib/ez-structures/home/ez_home_3_3.php' ) && $catalyst_child_home )
{
	// Require the specific Homepage Structure functions files.
	require_once( CATALYST_ROOT . '/lib/ez-structures/home/ez_home_3_3.php' );
	
	// Hook the Homepage Structure function into the 'catalyst_hook_home' Hook.
	add_action( 'catalyst_hook_home', 'ez_home_3_3' );
}

/****************************************
	Fat Footer
****************************************/

// Make sure the selected EZ Fat Footer Structure file is present in the specified Catalyst directory
// before proceeding to require the specified EZ Fat Footer Structure file and corresponding function.
if( file_exists( CATALYST_ROOT . '/lib/ez-structures/fat-footer/ez_fat_footer_2.php' ) )
{
	// Require the specific Fat Footer Structure functions file.
	require_once( CATALYST_ROOT . '/lib/ez-structures/fat-footer/ez_fat_footer_2.php' );
	
	// Hook the Fat Footer Structure function into the 'wp' Hook.
	add_action( 'wp', 'child_fat_footer' );
	/**
	 * Determine where NOT to display the Fat Footer section before hooking it in.
	 *
	 * @since 1.0
	 */
	function child_fat_footer()
	{
		global $catalyst_layout_id;
		// Add conditional tags to control where the Fat Footer Widget Area displays.
		if( substr( $catalyst_layout_id, 0, 21 ) == 'catalyst_landing_page' ) { return; }
		  if( ( is_page() || is_404() ) && !is_front_page() && !is_page_template( 'template-blog.php' ) && !is_page_template( 'template-blank-content.php' ) ) { return; }   if( is_page_template( 'template-blank-content.php' ) ) { return; }
		
		// Hook the specified Fat Footer Structure function into the catalyst_hook_after_after_header Hook.
		add_action( 'catalyst_hook_in_footer', 'ez_fat_footer_2' );
	}
}

// Filter in specific body classes based on option values.
add_filter( 'body_class', 'catalyst_child_body_classes' );
/**
 * Determine which classes will be filtered into the body class.
 *
 * @since 1.0
 * @return array of all classes to be filtered into the body class.
 */
function catalyst_child_body_classes( $classes )
{
	if( is_front_page() )
	{
		
		
		$classes[] = "ez-home-3-3";
		$classes[] = "home-top-triple";
		
		$classes[] = "home-bottom-triple";
		
		
	}
	
	
	$classes[] = "ez-fat-footer-2";
	
	
	return $classes;
}

/* Put Any Custom PHP Functions For Your WordPress Site In This File */

//end custom-functions.php

//end functions.php